@@ -2,7 +2,7 @@
 DSLIBRARY - run your data science code anywhere.
 
 """
-__version__ = "0.0.10"
+__version__ = "0.0.11"
 
 # environment variables
 from .front import ENV_DSLIBRARY_TARGET, ENV_DSLIBRARY_SPEC, ENV_DSLIBRARY_TOKEN
@@ -83,6 +83,19 @@ def instance(env: dict=None):
     return instantiate_class_and_args(target, DSLibrary)
 
 
+def run_model_method(method, dsl=None):
+    """
+    Call a method representing a model, passing along the parameters that come from either a supplied dslibrary instance
+    (dsl), or from the default dslibrary instance.
+
+    :param method:  Method to call.
+    :param dsl:     Dslibrary instance which will fetch the calling parameters.
+    :return:        Return value from the method (or captured KPIs if that is configured).
+    """
+    params = dsl.get_parameters() if dsl else get_parameters()
+    return ModelRunner(parameters=params).run_method(method)
+
+
 # set up default methods
 _DEFAULT = instance()
 get_parameter = _DEFAULT.get_parameter
