@@ -113,3 +113,16 @@ class TestToMMLibrary(unittest.TestCase):
             with dsl.open_model_binary("b", "r") as f_r:
                 self.assertEqual(f_r.read(), "BBB")
 
+    def test_named_filesystem_w_open_stream(self):
+        """
+        The open_stream() method (available in DSW, not MM) can be used to access a file from a named filesystem.
+        """
+        log = []
+        class MyMM(object):
+            def open_stream(self, filename, file_source, mode):
+                log.append((filename, file_source, mode))
+                return "FH"
+        dsl = DSLibraryViaMMLibrary(_mm=MyMM())
+        r = dsl.open_resource("name", mode="r", filesystem="fs123", bucket="b1")
+        assert r == "FH"
+        assert log == [('name', 'fs123:b1', 'r')]
